@@ -14,12 +14,12 @@ Bot::BasicBot - simple irc bot baseclass
     server => "irc.example.com",
     port   => "6667",
     channels => ["#bottest"],
-    
+
     nick      => "basicbot",
     alt_nicks => ["bbot", "simplebot"],
     username  => "bot",
     name      => "Yet Another Bot",
-    
+
     ignore_list => [qw(dipsy dadadodo laotse)],
 
     charset => "utf-8", # charset the bot assumes the channel is using
@@ -47,7 +47,7 @@ BEGIN {
   $Bot::BasicBot::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $Bot::BasicBot::VERSION = '0.83';
+  $Bot::BasicBot::VERSION = '0.85';
 }
 
 use strict;
@@ -59,7 +59,7 @@ use POE::Kernel;
 use POE::Session;
 use POE::Wheel::Run;
 use POE::Filter::Line;
-use POE::Component::IRC;
+use POE::Component::IRC::State;
 use POE::Component::IRC::Plugin::Connector;
 use Data::Dumper;
 use Text::Wrap ();
@@ -69,9 +69,9 @@ our @EXPORT  = qw( say emote );
 
 =head1 STARTING THE BOT
 
-=head2 new( key => value, .. )
+=head2 new
 
-Creates a new instance of the class.  Name value pairs may be passed
+Creates a new instance of the class. Key/value pairs may be passed
 which will have the same effect as calling the method of that name
 with the value supplied. Returns a Bot::BasicBot object, that you can
 call 'run' on later.
@@ -119,7 +119,7 @@ sub run {
         object_states => [
             $self => {
                 _start => "start_state",
-                _stop  => "stop_state",
+                die    => "die_state",
 
                 irc_001          => "irc_001_state",
                 irc_msg          => "irc_said_state",
@@ -133,20 +133,18 @@ sub run {
                 irc_part         => "irc_chanpart_state",
                 irc_kick         => "irc_kicked_state",
                 irc_nick         => "irc_nick_state",
-                irc_mode         => "irc_mode_state",
                 irc_quit         => "irc_quit_state",
 
                 fork_close       => "fork_close_state",
                 fork_error       => "fork_error_state",
 
-                irc_353          => "names_state",
                 irc_366          => "names_done_state",
 
                 irc_332          => "topic_raw_state",
                 irc_topic        => "topic_state",
 
                 irc_shutdown     => "shutdown_state",
-                
+
                 tick => "tick_state",
             }
         ]
@@ -177,7 +175,7 @@ In your Bot::BasicBot subclass, you want to override some of the following
 methods to define how your bot works. These are all object methods - the
 (implicit) first parameter to all of them will be the bot object.
 
-=head2 init()
+=head2 init
 
 called when the bot is created, as part of new(). Override to provide
 your own init. Return a true value for a successful init, or undef if
@@ -188,7 +186,7 @@ you failed, in which case new() will die.
 sub init { return 1; }
 
 
-=head2 said($args)
+=head2 said
 
 This is the main method that you'll want to override in your subclass -
 it's the one called by default whenever someone says anything that we
@@ -242,7 +240,7 @@ Returning undef will cause nothing to be said.
 
 sub said { return }
 
-=head2 emoted( $args )
+=head2 emoted
 
 This is a secondary method that you may wish to override. It gets called
 when someone in channel 'emotes', instead of talking. In its default
@@ -257,11 +255,11 @@ sub emoted {
     return shift->said(@_);
 }
 
-=head2 chanjoin( $mess )
+=head2 chanjoin
 
-Called when someone joins a channel. $mess is an object similar to a
-said() message, $mess->{who} is the nick of the user who joined,
-$mess->{channel} is the channel they joined.
+Called when someone joins a channel. It receives a hashref argument similar to
+the one received by said(). The key 'who' is the nick of the user who joined,
+while 'channel' is the channel they joined.
 
 This is a do-nothing implementation, override this in your subclass.
 
@@ -269,11 +267,11 @@ This is a do-nothing implementation, override this in your subclass.
 
 sub chanjoin { return }
 
-=head2 chanpart( $mess )
+=head2 chanpart
 
-Called when someone leaves a channel. $mess is an object similar to a
-said() message, $mess->{who} is the nick of the user who left,
-$mess->{channel} is the channel they left.
+Called when someone joins a channel. It receives a hashref argument similar to
+the one received by said(). The key 'who' is the nick of the user who parted,
+while 'channel' is the channel they parted.
 
 This is a do-nothing implementation, override this in your subclass.
 
@@ -281,14 +279,14 @@ This is a do-nothing implementation, override this in your subclass.
 
 sub chanpart { return }
 
-=head2 got_names( $mess )
+=head2 got_names
 
 Whenever we have been given a definitive list of 'who is in the channel',
-this function will be called. As usual, $mess is a hash. $mess->{channel}
-will be the channel we have information for, $mess->{names} is a hashref,
-where the keys are the nicks of the users, and the values are more hashes,
-containing the two keys 'op' and 'voice', indicating if the user is a chanop
-or voiced respectively.
+this function will be called. It receives a hash reference as an argument.
+The key 'channel' will be the channel we have information for, 'names' is a
+hashref where the keys are the nicks of the users, and the values are more
+hashes, containing the two keys 'op' and 'voice', indicating if the user is
+a chanop or voiced respectively.
 
 The reply value is ignored.
 
@@ -302,19 +300,21 @@ method won't be called when that happens.
 
 sub got_names { return }
 
-=head2 topic( $mess )
+=head2 topic
 
-Called when the topic of the channel changes. $mess->{channel} is the channel
-the topic was set in, $mess->{who} is the nick of the user who changed the
-channel, and $mess->{topic} will be the new topic of the channel.
+Called when the topic of the channel changes. It receives a hashref argument.
+The key 'channel' is the channel the topic was set in, and 'who' is the nick
+of the user who changed the channel, 'topic' will be the new topic of the
+channel.
 
 =cut
 
 sub topic { return }
 
-=head2 nick_change( $mess )
+=head2 nick_change
 
-When a user changes nicks, this will be called. $mess looks like
+When a user changes nicks, this will be called. It receives a hashref which
+will look like this:
 
   { from => "old_nick",
     to => "new_nick",
@@ -324,9 +324,10 @@ When a user changes nicks, this will be called. $mess looks like
 
 sub nick_change { return }
 
-=head2 kicked( $mess )
+=head2 kicked
 
-Called when a user is kicked from the channel. $mess looks like:
+Called when a user is kicked from the channel. It receives a hashref which
+will look like this:
 
   { channel => "#channel",
     who => "nick",
@@ -381,9 +382,9 @@ to the server
 
 sub connected { return }
 
-=head2 userquit( $mess )
+=head2 userquit
 
-$mess looks like
+Receives a hashref which will look like:
 
     { who => "nick that quit",
       body => "quit message",
@@ -402,12 +403,12 @@ sub userquit {
 There are a few methods you can call on the bot object to do things. These
 are as follows:
 
-=head2 schedule_tick(time)
+=head2 schedule_tick
 
-Causes the L<tick> event to be called in 'time' seconds (or 5 seconds if
-time is left unspecified). Note that if the tick event is due to be
-called already, this will override it, you can't schedule multiple
-future events with this funtction.
+Takes an integer as an argument. Causes the L<tick> event to be called after
+that many seconds (or 5 seconds if no argument is provided). Note that if the
+tick event is due to be called already, this will override it. You can't
+schedule multiple future events with this funtction.
 
 =cut
 
@@ -544,9 +545,10 @@ sub _fork_said {
     return;
 }
 
-=head2 say( key => value, .. )
+=head2 say
 
-Say something to someone.  You should pass the following arguments:
+Say something to someone. Takes a list of key/value pairs as arguments. You
+should pass the following arguments:
 
 =over 4
 
@@ -609,7 +611,7 @@ sub say {
     my $who = ( $args->{channel} eq "msg" ) ? $args->{who} : $args->{channel};
 
     unless ( $who && $body ) {
-        $self->log( "Can't PRIVMSG without target and body\n"
+        $self->log( "Can't send a message without target and body\n"
               . " called from "
               . ( [caller]->[0] )
               . " line "
@@ -625,18 +627,23 @@ sub say {
     # I think the Text::Wrap docs lie - it doesn't do anything special
     # in list context
     my @bodies = split(/\n+/, $wrapped);
-    
+
+    # Allows to override the default "PRIVMSG". Used by notice()
+    my $irc_command = defined $args->{irc_command} && $args->{irc_command} eq 'notice'
+        ? 'notice'
+        : 'privmsg';
+
     # post an event that will send the message
     for my $body (@bodies) {
         my ($enc_who, $enc_body) = $self->charset_encode($who, $body);
         #warn "$enc_who => $enc_body\n";
-        $poe_kernel->post( $self->{IRCNAME}, 'privmsg', $enc_who, $enc_body );
+        $poe_kernel->post( $self->{IRCNAME}, $irc_command, $enc_who, $enc_body );
     }
 
     return;
 }
 
-=head2 emote( key => value, .. )
+=head2 emote
 
 C<emote> will return data to channel, but emoted (as if you'd said "/me
 writes a spiffy new bot" in most clients). It takes the same arguments
@@ -682,15 +689,72 @@ sub emote {
     return;
 }
 
-=head2 reply($mess, $body)
+=head2 notice
 
-Reply to a message $mess. Will reply to an incoming message
-with the text '$body', in a privmsg if $mess was a privmsg, in channel if
-not, and prefixes if $mess was prefixed. Mostly a shortcut method - it's
-roughly equivalent to $mess->{body} = $body; $self->say($mess);
+C<notice> will send a IRC notice to the channel. This is typically used by bots
+to not break the IRC conversations flow. The message will appear as:
+
+    -nick- message here
+
+It takes the same arguments as C<say>, listed above. Example:
+
+    $bot->notice(
+        channel => '#bot_basicbot_test',
+        body => 'This is a notice'
+    );
 
 =cut
 
+sub notice {
+
+    if ( !ref( $_[0] ) ) {
+        print $_[0] . "\n";
+        return 1;
+    }
+    
+    my $self = shift;
+    my $args;
+    if (ref($_[0])) {
+        $args = shift;
+    } else {
+        my %args = @_;
+        $args = \%args;
+    }
+
+    # Don't modify '$args' hashref in-place, or we might
+    # make all subsequent calls into notices
+    return $self->say(
+        %{ $args },
+        irc_command => 'notice'
+    );
+
+}
+
+=head2 reply
+
+Takes two arguments, a hashref containing information about an incoming
+message, and a reply message. It will reply in a privmsg if the incoming one
+was a privmsg, in channel if not, and with prefixes if the incoming one was
+prefixed. Mostly a shortcut method - it's roughly equivalent to
+
+ $mess->{body} = $body;
+ $self->say($mess);
+
+=cut
+
+=head2 pocoirc
+
+Takes no arguments. Returns the underlying
+L<POE::Component::IRC::State|POE::Component::IRC::State> object used by
+Bot::BasicBot.
+
+=cut
+
+sub pocoirc {
+    my $self = shift;
+    return $self->{IRCOBJ};
+}
+
 sub reply {
     my $self = shift;
     my ($mess, $body) = @_;
@@ -699,16 +763,30 @@ sub reply {
     return $self->say(%hash);
 }
 
-
-
 =head2 channel_data
 
+Takes a channel names as a parameter, and returns a hash of hashes. The keys
+are the nicknames in the channel, the values are hashes containing the keys
+"voice" and "op", indicating whether these users are voiced or opped in the
+channel. This method is only here for backwards compatability. You'll probably
+get more use out of L<POE::Component::IRC::State|POE::Component::IRC::State>'s
+methods (which this method is merely a wrapper for). You can access the
+POE::Component::IRC::State object through Bot::BasicBot's C<pocoirc> method.
+
 =cut
 
 sub channel_data {
   my $self = shift;
   my $channel = shift or return;
-  return $self->{channel_data}{$channel}
+  my $channels = $self->{IRCOBJ}->channels();
+  return if !exists $channels->{$channel};
+
+  return { map {
+      $_ => {
+        op    => $self->{IRCOBJ}->is_channel_operator($channel, $_) || 0,
+        voice => $self->{IRCOBJ}->has_channel_voice($channel, $_) || 0,
+      }
+  } $self->{IRCOBJ}->channel_list($channel) };
 }
 
 =head1 ATTRIBUTES
@@ -918,20 +996,22 @@ sub flood {
     return $self->{flood};
 }
 
-=head1 STATES
+=head2 no_run
 
-These are the POE states that we register in order to listen for IRC
-events. For the most part you don't need to worry about these, unless
-you want to override them to do something clever.
-
-=head2 start_state
-
-Called when we start.  Used to fire a "connect to irc server event"
+Tells Bot::BasicBot to B<not> run the L<POE kernel|POE::Kernel> at the end
+of L<C<run>|/run>, in case you want to do that yourself.
 
 =cut
 
+sub no_run {
+    my $self = shift;
+    $self->{no_run} = shift if @_;
+    return $self->{no_run};
+}
+
 sub start_state {
     my ( $self, $kernel, $session ) = @_[ OBJECT, KERNEL, SESSION ];
+    $kernel->sig(DIE => 'die');
     $self->{kernel} = $kernel;
     $self->{session} = $session;
 
@@ -939,7 +1019,7 @@ sub start_state {
     $kernel->alias_set($self->{ALIASNAME});
     $kernel->delay('tick', 30);
 
-    $self->{IRCOBJ} = POE::Component::IRC->spawn( alias => $self->{IRCNAME} );
+    $self->{IRCOBJ} = POE::Component::IRC::State->spawn( alias => $self->{IRCNAME} );
     $self->{IRCOBJ}->plugin_add('Connector', POE::Component::IRC::Plugin::Connector->new());
     $kernel->post( $self->{IRCNAME}, 'register', 'all' );
 
@@ -963,22 +1043,13 @@ sub start_state {
     return;
 }
 
-=head2 stop_state
-
-Called when we're stopping.  Shutdown the bot correctly.
-
-=cut
-
-sub stop_state { }
-
-=head2 irc_001_state
-
-Called when we connect to the irc server.  This is used to tell
-the irc server that we'd quite like to join the channels.
-
-We also ignore ourselves.  We don't want to hear what we have to say.
-
-=cut
+sub die_state {
+    my ($kernel, $self, $ex) = @_[KERNEL, OBJECT, ARG1];
+    warn $ex->{error_str};
+    $self->{IRCOBJ}->yield('shutdown');
+    $kernel->sig_handled();
+    return;
+}
 
 sub irc_001_state {
     my ( $self, $kernel ) = @_[ OBJECT, KERNEL ];
@@ -998,39 +1069,18 @@ sub irc_001_state {
     return;
 }
 
-=head2 irc_disconnected_state
-
-Called if we are disconnected from the server. Logs the error.
-
-=cut
-
 sub irc_disconnected_state {
     my ( $self, $kernel, $server ) = @_[ OBJECT, KERNEL, ARG0 ];
     $self->log("Lost connection to server $server.\n");
     return;
 }
 
-=head2 irc_error_state
-
-Called if there is an irc server error. Logs the error.
-
-=cut
-
 sub irc_error_state {
     my ( $self, $err, $kernel ) = @_[ OBJECT, ARG0, KERNEL ];
     $self->log("Server error occurred! $err\n");
     return;
 }
 
-=head2 irc_kicked_state
-
-Called on kick.  If we're kicked then it's best to do
-nothing.  Bots are normally called in wrapper that restarts them
-if we die, which may end us up in a busy loop.  Anyway, if we're not
-wanted, the best thing to do would be to hang around off channel.
-
-=cut
-
 sub irc_kicked_state {
     my ($self, $kernel, $heap, $session) = @_[OBJECT, KERNEL, HEAP, SESSION];
     my ($nickstring, $channel, $kicked, $reason) = @_[ARG0..$#_];
@@ -1040,122 +1090,37 @@ sub irc_kicked_state {
     return;
 }
 
-=head2 irc_join_state
-
-Called if someone joins.  Used for nick tracking
-
-=cut
-
 sub irc_join_state {
     my ( $self, $nick ) = @_[ OBJECT, ARG0 ];
     return;
 }
 
-=head2 irc_nick_state
-
-Called if someone changes nick.  Used for nick tracking.
-
-=cut
-
 sub irc_nick_state {
     my ( $self, $nick, $newnick ) = @_[ OBJECT, ARG0, ARG1 ];
     $nick = $self->nick_strip($nick);
-    for my $channel (keys( %{ $self->{channel_data} } )) {
-        $self->{channel_data}{$channel}{$newnick}
-          = delete $self->{channel_data}{$channel}{$nick};
-    }
     $self->nick_change($nick, $newnick);
     return;
 }
 
-=head2 irc_mode_state
-
-=cut
-
-## no critic (ControlStructures::ProhibitCascadingIfElse)
-sub irc_mode_state {
-    my ($self, $kernel, $session) = @_[OBJECT, KERNEL, SESSION];
-    my ($nickstring, $channel, $mode, @ops) = @_[ARG0..$#_];
-    my $nick = $self->nick_strip($nickstring);
-    $mode =~ s/^(.)//;
-    my $added = $1 eq '+' ? 1 : 0;
-    my @modes = split(//, $mode);
-    for my $who (@ops) {
-        my $current = $self->{channel_data}{$channel}{$who};
-
-        my $op = shift(@modes);
-
-        if ($added && $op eq 'o') {
-          $current->{op} = 1;
-          $current->{voice} = 0;
-
-        } elsif ($added && $op eq 'v') {
-          $current->{voice} = 1 unless $current->{op};
-
-        } elsif (!$added && $op eq 'o') {
-          $current->{op} = 0;
-          $current->{voice} = 0;
-
-        } elsif (!$added && $op eq 'v') {
-          $current->{voice} = 1 unless $current->{op};
-        }
-
-        $self->{channel_data}{$channel}{$who} = $current;
-    }
-    return;
-}
-
-
-=head2 irc_quit_state
-
-=cut
-
 sub irc_quit_state {
     my ($self, $kernel, $session) = @_[OBJECT, KERNEL, SESSION];
     my ($nick, $message) = @_[ARG0..$#_];
 
     $nick = $self->nick_strip($nick);
-
     $self->userquit({ who => $nick, body => $message });
-
-    # do this second, so that the userquit implementor has a chance to see
-    # which channels they left
-    $self->_remove_from_all_channels( $nick );
     return;
 }
 
-=head2 irc_said_state
-
-Called if we recieve a private or public message.  This
-formats it into a nicer format and calls 'said'
-
-=cut
-
 sub irc_said_state {
     irc_received_state( 'said', 'say', @_ );
     return;
 }
 
-=head2 irc_emoted_state
-
-Called if someone "emotes" on channel, rather than directly saying
-something. Currently passes the emote striaght to C<irc_said_state>
-which deals with it as if it was a spoken phrase.
-
-=cut
-
 sub irc_emoted_state {
     irc_received_state( 'emoted', 'emote', @_ );
     return;
 }
 
-=head2 irc_received_state
-
-Called by C<irc_said_state> and C<irc_emoted_state> in order to format
-channel input into a more copable-with format.
-
-=cut
-
 sub irc_received_state {
     my $received = shift;
     my $respond  = shift;
@@ -1227,19 +1192,13 @@ sub irc_received_state {
     return unless defined $return;
 
     # a string?  Say it how we were addressed then
-    unless ( ref($return) ) {
+    if (!ref $return && length $return) {
         $mess->{body} = $return;
         $self->$respond($mess);
         return;
     }
 }
 
-=head2 irc_chanjoin_state
-
-Called if someone joins a channel.
-
-=cut
-
 sub irc_chanjoin_state {
     my $self = $_[OBJECT];
     my ($channel, $nick) = @_[ ARG1, ARG0 ];
@@ -1249,17 +1208,10 @@ sub irc_chanjoin_state {
       push @channels, $channel unless grep { $_ eq $channel }  @channels;
       $self->channels(\@channels);
     }
-    $_[OBJECT]->_add_to_channel( $channel, $nick );
     irc_chan_received_state( 'chanjoin', 'say', @_ );
     return;
 }
 
-=head2 irc_chanpart_state
-
-Called if someone parts a channel.
-
-=cut
-
 sub irc_chanpart_state {
     my $self = $_[OBJECT];
     my ($channel, $nick) = @_[ ARG1, ARG0 ];
@@ -1269,18 +1221,10 @@ sub irc_chanpart_state {
       @channels = grep { $_ ne $channel } @channels;
       $self->channels(\@channels);
     }
-    $_[OBJECT]->_remove_from_channel( $channel, $nick );
     irc_chan_received_state( 'chanpart', 'say', @_ );
     return;
 }
 
-=head2 irc_chan_received_state
-
-Called by C<irc_chanjoin_state> and C<irc_chanpart_state> in order to format
-channel joins and parts into a more copable-with format.
-
-=cut
-
 sub irc_chan_received_state {
     my $received = shift;
     my $respond  = shift;
@@ -1313,37 +1257,14 @@ sub irc_chan_received_state {
 }
 
 
-=head2 fork_close_state
-
-Called whenever a process forked by L<POE::Wheel::Run> (in C<forkit>)
-terminates, and allows us to delete the object and associated data
-from memory.
-
-=cut
-
 sub fork_close_state {
     my ( $self, $wheel_id ) = @_[ 0, ARG0 ];
     delete $self->{forks}->{$wheel_id};
     return;
 }
 
-=head2 fork_error_state
-
-Called if a process forked by L<POE::Wheel::Run> (in C<forkit>) hits
-an error condition for any reason. Does nothing, but can be overloaded
-in derived classes to be more useful
-
-=cut
-
 sub fork_error_state { }
 
-=head2 tick_state
-
-the POE state for the tick event. Reschedules a tick event for the future
-if the tick method returned a value.
-
-=cut
-
 sub tick_state {
     my ( $self, $kernel, $heap ) = @_[ OBJECT, KERNEL, HEAP ];
     my $delay = $self->tick();
@@ -1351,75 +1272,13 @@ sub tick_state {
     return;
 }
 
-=head2 names_state
-
-=cut
-
-sub names_state {
-  my ($self, $kernel, $server, $message) = @_[OBJECT, KERNEL, ARG0, ARG1];
-  my (undef, $channel, @names) = split(/\s/, $message);
-  $names[0] =~ s/^\://; # FFS
-
-  # while we get names responses, build an 'in progress' list of people.
-  my $building = $self->{building_channel_data}{$channel} ||= {};
-
-  for my $nick (@names) {
-    my ($op, $voice);
-    $op = ($nick =~ s/^@//) ? 1 : 0;
-    $voice = ($nick =~ s/^\+//) ? 1 : 0;
-    $building->{$nick} = {
-      op => $op,
-      voice => $voice,
-    }
-  }
-  return;
-}
-
-=head2 names_done_state
-
-=cut
-
 sub names_done_state {
   my ($self, $kernel, $server, $message) = @_[OBJECT, KERNEL, ARG0, ARG1];
   my ($channel) = split(/\s/, $message);
-
-  # we have the complete list of names in the channel. Remove the 'in progress'
-  # list, and put it as the definitive 'list of people'.
-  my $built = delete $self->{building_channel_data}{$channel};
-  return unless $built;
-  $self->{channel_data}{$channel} = $built;
-  $self->got_names({ channel => $channel, names => $built });
+  $self->got_names({ channel => $channel, names => $self->channel_data($channel) });
   return;
 }
 
-
-sub _add_to_channel {
-  my ($self, $channel, $nick, $ops) = @_;
-  $ops ||= { op => 0, voice => 0 };
-  $self->{channel_data}{$channel}{$nick} = $ops;
-  return;
-}
-
-sub _remove_from_channel {
-  my ($self, $channel, $nick) = @_;
-  delete $self->{channel_data}{$channel}{$nick};
-  return;
-}
-
-sub _remove_from_all_channels {
-  my ($self, $nick) = @_;
-  for my $channel (keys %{ $self->{channel_data} }) {
-    if ( $self->{channel_data}{$channel}{$nick} ) {
-      $self->_remove_from_channel( $channel, $nick );
-    }
-  }
-  return;
-}
-
-=head2 topic_raw_state
-
-=cut
-
 sub topic_raw_state {
   my ($self, $kernel, $server, $raw) = @_[OBJECT, KERNEL, ARG0, ARG1];
   my ($channel, $topic) = split(/ :/, $raw, 2);
@@ -1427,10 +1286,6 @@ sub topic_raw_state {
   return;
 }
 
-=head2 topic_state
-
-=cut
-
 sub topic_state {
   my ($self, $kernel, $nickraw, $channel, $topic)
     = @_[OBJECT, KERNEL, ARG0, ARG1, ARG2];
@@ -1439,10 +1294,6 @@ sub topic_state {
   return;
 }
 
-=head2 shutdown_state
-
-=cut
-
 sub shutdown_state {
     my ($kernel, $self) = @_[KERNEL, OBJECT];
     $kernel->delay('tick');
@@ -1524,7 +1375,7 @@ sub nick_strip {
     return $nick;
 }
 
-=head2 charset_decode( foo, bar, baz )
+=head2 charset_decode
 
 Converts a string of bytes into a perl string, using the bot's L<charset>.
 (under perls before 5.8, just returns the thing it's passed.
@@ -1562,7 +1413,7 @@ sub charset_decode {
   return @r;
 }
 
-=head2 charset_encode( foo, bar, baz )
+=head2 charset_encode
 
 Converts a list of perl strings into a list of byte sequences, using
 the bot's charset. See L<charset_decode>.
